@@ -13,7 +13,7 @@
 #' @examples
 #' kmneighbourhood(c(1,1,0,0), xpl$space)
 #'
-#' @family Neighbourhood & fringe
+#' @family Fringes & paths
 #'
 #' @export
 kmneighbourhood <- function(state, struct, include = FALSE) {
@@ -38,7 +38,7 @@ kmneighbourhood <- function(state, struct, include = FALSE) {
   )
   if (include) n <- rbind(n, state)
   colnames(n) <- colnames(struct)
-  class(n) <- unique(c("kmfamset", class(n)))
+  class(n) <- unique(c("kmneighbourhood", "kmfamset", class(n)))
   n
 }
 
@@ -60,7 +60,7 @@ kmneighbourhood <- function(state, struct, include = FALSE) {
 #' @examples
 #' kmnneighbourhood(c(1,1,0,0), xpl$space, 2)
 #'
-#' @family Neighbourhood & fringe
+#' @family Fringes & paths
 #'
 #' @export
 kmnneighbourhood <- function(state, struct, distance, include=FALSE) {
@@ -86,6 +86,6 @@ kmnneighbourhood <- function(state, struct, distance, include=FALSE) {
   )
   if (include) n <- rbind(n, state)
   colnames(n) <- colnames(struct)
-  class(n) <- unique(c("kmfamset", class(n)))
+  class(n) <- unique(c("kmneighbourhood", "kmfamset", class(n)))
   n
 }
