@@ -12,5 +12,7 @@
 #' @export
 kmsf2basis <- function(sf) {
   noc <- dim(sf)[2]
-  unique(apply(as.matrix(sf[, 2:noc]), 2, as.numeric))
+  bas <- unique(apply(as.matrix(sf[, 2:noc]), 2, as.numeric))
+  class(bas) <- unique(c("kmbasis", "kmfamset", class(bas)))
+  bas
 }
